==> qtjambi-activex-debuginfo-windows-x64-5.15.18.jar: sources/QtJambiActiveX/QAxScript_shell.h <==
#ifndef QAXSCRIPT_SHELL_H
#define QAXSCRIPT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#if __has_include(<ActiveQt/qaxscript.h>)
#include <ActiveQt/qaxscript.h>
#endif
#include <QtJambi/QtJambiAPI>
#if __has_include(<ActiveQt/qaxbase.h>)
#include <ActiveQt/qaxbase.h>
#endif
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


#if defined(Q_OS_WIN)

class QAxScript_shell : public QAxScript, public QtJambiShellInterface
{
public:
    QAxScript_shell(const QString& name0, QAxScriptManager* manager1);
    ~QAxScript_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxScript_access : public QAxScript
{
};

#endif // defined(Q_OS_WIN)
#endif // QAXSCRIPT_SHELL_H

==> qtjambi-activex-debuginfo-windows-x64-6.5.3.jar: sources/QtJambiActiveX/QAxScript_shell.h <==
#ifndef QAXSCRIPT_SHELL_H
#define QAXSCRIPT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <ActiveQt/qaxscript.h>
#include <QtJambi/QtJambiAPI>
#include <ActiveQt/qaxbase.h>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtJambi/RegistryAPI>


class QAxScript_shell : public QAxScript, public QtJambiShellInterface
{
public:
    QAxScript_shell(const QString& name0, QAxScriptManager* manager1);
    ~QAxScript_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAxScript_access : public QAxScript
{
};

#endif // QAXSCRIPT_SHELL_H
